@@ -12,11 +12,11 @@ Smart::Comments::Log4perl - An extension of Smart::Comments to utilize Log::Log4
 
 =head1 VERSION
 
-Version 1.00
+Version 1.002
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.002';
 our $INITIALIZED;
 our $LAYOUT;
 our $CONFIG_FILE = $ENV{'SCL4P_CONFIG'};
@@ -190,6 +190,9 @@ sub PRINT
 {
 	shift;
 	local *STDERR = *L4P_ORIGINAL_STDERR;
+	# Kind of a magic number, needed to step back out of these frames deep enough to find where the smart::comment was originally
+	#   So, Smart::Comments::Dump, PRINT, LOGGER_DISPATCH, etc.
+	local $Log::Log4perl::caller_depth = 4;
 	return unless exists $LOGGER_DISPATCH{$LOG_LEVEL};
 	return $LOGGER_DISPATCH{$LOG_LEVEL}->(@_);
 }
